<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.13
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2021 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Base\SmartTags;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

use FPFramework\Base\Filter;

class QueryString extends SmartTag
{
	/**
	 * Gets all available Query Strings
	 *
	 * @return array
	 */
	public function fetchAll()
	{
        $query = $this->factory->getQueryStrings();
		
		// Add an empty query parameter in order to force the cleaning of unreplaced tags.
		if (empty($query))
		{
			return ['' => ''];
		}
        
        $data = [];

		// Sanitize all query parameters by removing HTML.
        $filter = Filter::getInstance();

		foreach ($query as $key => &$param)
		{
			$data['querystring.' . $key] = $filter->clean($param, 'HTML');
		}

		return $data;
	}

	/**
	 * Fetch value of a specific query string
	 * 
	 * @param   string  $key
	 * 
	 * @return  string
	 */
	public function fetchValue($key)
	{
		if (!$key)
		{
			return '';
		}

		if (!is_string($key))
		{
			return '';
		}
		
        $query = $this->factory->getQueryStrings();

		if (empty($query))
		{
			return '';
		}
        
		// Sanitize all query parameters by removing HTML.
		$filter = Filter::getInstance();
		
		foreach ($query as $q_key => &$param)
		{
			if (strtolower($q_key) != strtolower($key))
			{
				continue;
			}
			
			return $filter->clean($param, 'HTML');
		}

		return '';
	}
}