<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.13
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2021 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}
$templates = (array) $this->data->get('templates', []);
if (!$templates)
{
    return;
}
$license_type = $this->data->get('license_type', null);
$favorites = (array) $this->data->get('favorites', []);
$plugin = $this->data->get('plugin', '');
$template_use_url = $this->data->get('template_use_url', '');
foreach ($templates as $group_key => $groups) {
    $key = strtolower(esc_attr($group_key));
    foreach ($groups as $template_key => $template) {
        if (!isset($template->id))
        {
            continue;
        }
        $type = isset($template->tags) && in_array('pro', $template->tags) ? 'pro' : 'free';

        // render only templates that are the same type as the given license type
        if (!is_null($license_type) && $type != $license_type)
        {
            continue;
        }

        // add a space to type before it gets appended to data-cat attribute
        $type = ' ' . $type;
        
        // If not available, its missing the actual template which means that its a pro template
        $is_available = isset($template->template);
        $is_fav = array_key_exists($template->id, $favorites);
        $image = isset($template->image) ? $template->image : '';
        $link_preview = home_url('?' . $plugin . '_preview_template=' . base64_encode($template->alias));
        $link_use = admin_url($template_use_url . $template->alias);
        ?>
        <div class="ts-item <?php echo trim($template->css_class) ?>" data-id="<?php echo esc_attr($template->id); ?>" data-cat="<?php echo esc_attr($key . $type); ?>" data-title="<?php echo esc_attr($template->title); ?>">
            <span class="ts-item-wrap">
                <img src="<?php echo esc_url($image); ?>"/>
                <span class="ts-item-hover">
                    <?php
                    // we have a template to use
                    if ($is_available)
                    {
                    ?>
                    <a class="ts-preview parent" href="<?php echo esc_url($link_use); ?>">
                        <span class="dashicons dashicons-upload"></span>
                        <span class="ts-title"><?php echo esc_html($template->title); ?></span>
                    </a>
                    <?php
                    }
                    else
                    {
                        // no template, free user, show upgrade to pro message
                        if ($license_type == 'free')
                        {
                        ?>
                        <span class="ts-preview parent">
                            <span class="ts-dk margin-bottom-1"><?php echo fpframework()->_('FPF_UPGRADE_TO_PRO_TO_UNLOCK_TEMPLATE') ?></span>
                            <?php
                            echo \FPFramework\Helpers\HTML::renderProButton(fpframework()->_('FPF_UPGRADE_TO_PRO'), $template->title . ' ' . fpframework()->_('FPF_TEMPLATE'));
                            ?>
                        </span>
                        <?php
                        }
                        // no template, free or pro user, tell them to enter license & refresh templates
                        else
                        {
                        ?>
                        <span class="ts-preview parent">
                            <span class="ts-dk"><?php echo esc_html(fpframework()->_('FPF_ENTER_LICENSE_TO_USE_TEMPLATE')); ?></span>
                            <?php
                            if (FBOX_LICENSE_TYPE == 'free')
                            {
                                echo \FPFramework\Helpers\HTML::renderProButton(fpframework()->_('FPF_UPGRADE_TO_PRO'), $template->title . ' ' . fpframework()->_('FPF_TEMPLATE'));
                            }
                            ?>
                        </span>
                        <?php
                        }
                    }
                    ?>
                    <span class="ts-buttons">
                        <?php if ($is_available) { ?>
                        <span>
                            <a class="preview_template" title="<?php echo esc_attr(fpframework()->_('FPF_PREVIEW_TEMPLATE_FRONTEND')); ?>" target="_blank" href="<?php echo esc_url($link_preview); ?>">
                                <span class="dashicons dashicons-visibility"></span>
                                <?php echo esc_html(fpframework()->_('FPF_PREVIEW')); ?>
                            </a>
                        </span>
                        <?php } else { //following span is used to satisfy flex and display the "favorites" icon on the right side ?>
                        <span></span>
                        <?php } ?>
                        <span>
                            <?php if (isset($template->fields->note) && !empty($template->fields->note)) { ?>
                                <span class="info dashicons dashicons-editor-help" title="<?php echo esc_attr($template->fields->note); ?>"></span>
                            <?php } ?>

                            <a class="favorite_icon <?php echo $is_fav ? 'active' : '' ?>" title="<?php echo esc_attr(fpframework()->_('FPF_LIBRARY_SAVE_TEMPLATE_FAVORITES')); ?>" href="#">
                                <span class="up dashicons dashicons-heart"></span>
                                <span class="active dashicons dashicons-heart"></span>
                            </a>
                        </span>
                    </span>
                </span>
            </span>
        </div>
        <?php
    }
}